import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Generates an API key to access a SvectorDB serverless vector database, sign up at https://svectordb.com to get started
 *
 * @schema CfnApiKeyProps
 */
export interface CfnApiKeyProps {
    /**
     * (Advanced use cases only) - Custom endpoint URL for contacting the SvectorDB API
     *
     * @schema CfnApiKeyProps#EndpointUrl
     */
    readonly endpointUrl?: string;
    /**
     * Integration ID
     *
     * @schema CfnApiKeyProps#IntegrationId
     */
    readonly integrationId: string;
    /**
     * Database ID
     *
     * @schema CfnApiKeyProps#DatabaseId
     */
    readonly databaseId: string;
}
/**
 * Converts an object of type 'CfnApiKeyProps' to JSON representation.
 */
export declare function toJson_CfnApiKeyProps(obj: CfnApiKeyProps | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `SvectorDB::VectorDatabase::ApiKey`
 *
 * @cloudformationResource SvectorDB::VectorDatabase::ApiKey
 * @stability external
 * @link http://unknown-url
 */
export declare class CfnApiKey extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "SvectorDB::VectorDatabase::ApiKey";
    /**
     * Resource props.
     */
    readonly props: CfnApiKeyProps;
    /**
     * Attribute `SvectorDB::VectorDatabase::ApiKey.ApiKey`
     * @link http://unknown-url
     */
    readonly attrApiKey: string;
    /**
     * Create a new `SvectorDB::VectorDatabase::ApiKey`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnApiKeyProps);
}
